@@ -321,11 +321,12 @@ class Beskar():
         )
 
         # If the user provided a base RBAC policy, lets consume it
-        if app.config.get("RBAC_POLICY"):
+        if app.config.get("BESKAR_RBAC_POLICY"):
             try:
-                self.rbac_definitions = normalize_rbac(app.config.get("RBAC_POLICY"))
+                self.rbac_definitions = normalize_rbac(app.config.get("BESKAR_RBAC_POLICY"))
             except Exception as e:
-                raise ConfigurationError(f'Failure loading supplied RBAC_POLICY from config: {e}')
+                raise ConfigurationError(f'Failure loading supplied BESKAR_RBAC_POLICY '
+                                         f'from config: {e}') from e
 
         if isinstance(self.access_lifespan, dict):
             self.access_lifespan = pendulum.duration(**self.access_lifespan)
